.waf--html-field-wrapper,
.waf--submit-btn-container {
  margin-top: 2rem; }

.waf--field-container {
  margin-top: 2rem; }
  .waf--field-container input[type=date],
  .waf--field-container input[type=email],
  .waf--field-container input[type=number],
  .waf--field-container input[type=text],
  .waf--field-container input[type=text],
  .waf--field-container input[type=url],
  .waf--field-container select,
  .waf--field-container textarea {
    display: block;
    padding: 1.5rem;
    border-radius: 4px;
    width: 100%;
    border: 1px solid #e5e5e5; }
  .waf--field-container .waf--field-label {
    font-size: 2rem; }
  .waf--field-container .waf--field-help-text {
    font-size: 1rem;
    opacity: 0.8; }
  .waf--field-container .waf--choice-inline {
    display: inline;
    margin-right: 50px; }
  .waf--field-container .waf--radio-list {
    list-style: none;
    margin-left: 0;
    padding-left: 0; }
  .waf--field-container .waf--field-label-choice {
    padding-left: 10px; }

.waf--field-container--error input[type=date],
.waf--field-container--error input[type=email],
.waf--field-container--error input[type=number],
.waf--field-container--error input[type=text],
.waf--field-container--error input[type=text],
.waf--field-container--error input[type=url],
.waf--field-container--error select,
.waf--field-container--error textarea {
  border-color: #f24949; }

.waf--submit-btn {
  padding: 1rem 2rem; }

.waf--field-error {
  color: #f24949;
  font-size: 1rem;
  margin-top: 0.5rem; }

.waf--datepicker-container {
  position: relative; }

.waf--form .datepicker {
  display: none; }

.waf--form .datepicker.active {
  display: block; }

.waf--form .datepicker-dropdown {
  position: absolute;
  top: 0;
  left: 0;
  z-index: 20;
  padding-top: 4px; }

.waf--form .datepicker-dropdown.datepicker-orient-top {
  padding-top: 0;
  padding-bottom: 4px; }

.waf--form .datepicker-picker {
  display: inline-block;
  border-radius: 4px;
  background-color: white; }

.waf--form .datepicker-dropdown .datepicker-picker {
  box-shadow: 0 2px 3px rgba(10, 10, 10, 0.1), 0 0 0 1px rgba(10, 10, 10, 0.1); }

.waf--form .datepicker-picker span {
  display: block;
  flex: 1;
  border: 0;
  border-radius: 4px;
  cursor: default;
  text-align: center;
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none; }

.waf--form .datepicker-main {
  padding: 2px; }

.waf--form .datepicker-footer {
  box-shadow: inset 0 1px 1px rgba(10, 10, 10, 0.1);
  background-color: whitesmoke; }

.waf--form .datepicker-controls, .waf--form .datepicker-view, .waf--form .datepicker-view .days-of-week, .waf--form .datepicker-grid {
  display: flex; }

.waf--form .datepicker-grid {
  flex-wrap: wrap; }

.waf--form .datepicker-view .dow, .waf--form .datepicker-view .days .datepicker-cell {
  flex-basis: 14.28571%; }

.waf--form .datepicker-view.datepicker-grid .datepicker-cell {
  flex-basis: 25%; }

.waf--form .datepicker-view .week, .waf--form .datepicker-cell {
  height: 2.25rem;
  line-height: 2.25rem; }

.waf--form .datepicker-title {
  box-shadow: inset 0 -1px 1px rgba(10, 10, 10, 0.1);
  background-color: whitesmoke;
  padding: 0.375rem 0.75rem;
  text-align: center;
  font-weight: 700; }

.waf--form .datepicker-header .datepicker-controls {
  padding: 2px 2px 0; }

.waf--form .datepicker-controls .button {
  display: inline-flex;
  position: relative;
  align-items: center;
  justify-content: center;
  margin: 0;
  border: 1px solid #dbdbdb;
  border-radius: 4px;
  box-shadow: none;
  background-color: white;
  cursor: pointer;
  padding: calc(0.375em - 1px) 0.75em;
  height: 2.25em;
  vertical-align: top;
  text-align: center;
  line-height: 1.5;
  white-space: nowrap;
  color: #363636;
  font-size: 1rem; }

.waf--form .datepicker-controls .button:focus, .waf--form .datepicker-controls .button:active {
  outline: none; }

.waf--form .datepicker-controls .button:hover {
  border-color: #b5b5b5;
  color: #363636; }

.waf--form .datepicker-controls .button:focus {
  border-color: #3273dc;
  color: #363636; }

.waf--form .datepicker-controls .button:focus:not(:active) {
  box-shadow: 0 0 0 0.125em rgba(50, 115, 220, 0.25); }

.waf--form .datepicker-controls .button:active {
  border-color: #4a4a4a;
  color: #363636; }

.waf--form .datepicker-controls .button[disabled] {
  cursor: not-allowed; }

.waf--form .datepicker-header .datepicker-controls .button {
  border-color: transparent;
  font-weight: bold; }

.waf--form .datepicker-header .datepicker-controls .button:hover {
  background-color: #f9f9f9; }

.waf--form .datepicker-header .datepicker-controls .button:focus:not(:active) {
  box-shadow: 0 0 0 0.125em rgba(255, 255, 255, 0.25); }

.waf--form .datepicker-header .datepicker-controls .button:active {
  background-color: #f2f2f2; }

.waf--form .datepicker-header .datepicker-controls .button[disabled] {
  box-shadow: none; }

.waf--form .datepicker-footer .datepicker-controls .button {
  margin: calc(0.375rem - 1px) 0.375rem;
  border-radius: 2px;
  width: 100%;
  font-size: 0.75rem; }

.waf--form .datepicker-controls .view-switch {
  flex: auto; }

.waf--form .datepicker-controls .prev-btn,
.waf--form .datepicker-controls .next-btn {
  padding-right: 0.375rem;
  padding-left: 0.375rem;
  width: 2.25rem; }

.waf--form .datepicker-controls .prev-btn.disabled,
.waf--form .datepicker-controls .next-btn.disabled {
  visibility: hidden; }

.waf--form .datepicker-view .dow {
  height: 1.5rem;
  line-height: 1.5rem;
  font-size: 0.875rem;
  font-weight: 700; }

.waf--form .datepicker-view .week {
  width: 2.25rem;
  color: #b5b5b5;
  font-size: 0.75rem; }

@media (max-width: 22.5rem) {
  .waf--form .datepicker-view .week {
    width: 1.96875rem; } }

.waf--form .datepicker-grid {
  width: 15.75rem; }

@media (max-width: 22.5rem) {
  .waf--form .calendar-weeks + .days .datepicker-grid {
    width: 13.78125rem; } }

.waf--form .datepicker-cell:not(.disabled):hover {
  background-color: #f9f9f9;
  cursor: pointer; }

.waf--form .datepicker-cell.focused:not(.selected) {
  background-color: #e8e8e8; }

.waf--form .datepicker-cell.selected, .waf--form .datepicker-cell.selected:hover {
  background-color: #3273dc;
  color: #fff;
  font-weight: 600; }

.waf--form .datepicker-cell.disabled {
  color: #dbdbdb; }

.waf--form .datepicker-cell.prev:not(.disabled), .waf--form .datepicker-cell.next:not(.disabled) {
  color: #7a7a7a; }

.waf--form .datepicker-cell.highlighted:not(.selected):not(.range):not(.today) {
  border-radius: 0;
  background-color: whitesmoke; }

.waf--form .datepicker-cell.highlighted:not(.selected):not(.range):not(.today):not(.disabled):hover {
  background-color: #eeeeee; }

.waf--form .datepicker-cell.highlighted:not(.selected):not(.range):not(.today).focused {
  background-color: #e8e8e8; }

.waf--form .datepicker-cell.today:not(.selected) {
  background-color: #00d1b2; }

.waf--form .datepicker-cell.today:not(.selected):not(.disabled) {
  color: #fff; }

.waf--form .datepicker-cell.today.focused:not(.selected) {
  background-color: #00c4a7; }

.waf--form .datepicker-cell.range-start:not(.selected), .waf--form .datepicker-cell.range-end:not(.selected) {
  background-color: #b5b5b5;
  color: #fff; }

.waf--form .datepicker-cell.range-start.focused:not(.selected), .waf--form .datepicker-cell.range-end.focused:not(.selected) {
  background-color: #afafaf; }

.waf--form .datepicker-cell.range-start {
  border-radius: 4px 0 0 4px; }

.waf--form .datepicker-cell.range-end {
  border-radius: 0 4px 4px 0; }

.waf--form .datepicker-cell.range {
  border-radius: 0;
  background-color: #dbdbdb; }

.waf--form .datepicker-cell.range:not(.disabled):not(.focused):not(.today):hover {
  background-color: #d5d5d5; }

.waf--form .datepicker-cell.range.disabled {
  color: #c2c2c2; }

.waf--form .datepicker-cell.range.focused {
  background-color: #cfcfcf; }

.waf--form .datepicker-view.datepicker-grid .datepicker-cell {
  height: 4.5rem;
  line-height: 4.5rem; }

.waf--form .datepicker-input.in-edit {
  border-color: #2366d1; }

.waf--form .datepicker-input.in-edit:focus, .waf--form .datepicker-input.in-edit:active {
  box-shadow: 0 0 0.25em 0.25em rgba(35, 102, 209, 0.2); }


/*# sourceMappingURL=style.css.map*/